@@ -12,9 +12,10 @@ class ZipFileSystem(AbstractFileSystem):
 
     This class is pickleable, but not necessarily thread-safe
     """
+
     root_marker = ""
 
-    def __init__(self, fo='', mode='r', **storage_options):
+    def __init__(self, fo="", mode="r", **storage_options):
         """
         Parameters
         ----------
@@ -28,25 +29,27 @@ class ZipFileSystem(AbstractFileSystem):
             other parameters for requests
         """
         AbstractFileSystem.__init__(self)
-        if mode != 'r':
+        if mode != "r":
             raise ValueError("Only read from zip files accepted")
         self.in_fo = fo
         if isinstance(fo, str):
             files = open_files(fo)
             if len(files) != 1:
-                raise ValueError('Path "{}" did not resolve to exactly'
-                                 'one file: "{}"'.format(fo, files))
+                raise ValueError(
+                    'Path "{}" did not resolve to exactly'
+                    'one file: "{}"'.format(fo, files)
+                )
             fo = files[0]
         self.fo = fo.__enter__()  # the whole instance is a context
         self.zip = zipfile.ZipFile(self.fo)
-        self.block_size = storage_options.pop('block_size', DEFAULT_BLOCK_SIZE)
+        self.block_size = storage_options.pop("block_size", DEFAULT_BLOCK_SIZE)
         self.kwargs = storage_options
         self.dir_cache = None
 
     @classmethod
     def _strip_protocol(cls, path):
         # zip file paths are always relative to the archive root
-        return super()._strip_protocol(path).lstrip('/')
+        return super()._strip_protocol(path).lstrip("/")
 
     def _get_dirs(self):
         if self.dir_cache is None:
@@ -54,56 +57,63 @@ class ZipFileSystem(AbstractFileSystem):
             self.dir_cache = {}
             for z in files:
                 f = {s: getattr(z, s) for s in zipfile.ZipInfo.__slots__}
-                f.update({'name': z.filename, 'size': z.file_size,
-                          'type': ('directory' if z.is_dir() else 'file')})
-                self.dir_cache[f['name']] = f
+                f.update(
+                    {
+                        "name": z.filename,
+                        "size": z.file_size,
+                        "type": ("directory" if z.is_dir() else "file"),
+                    }
+                )
+                self.dir_cache[f["name"]] = f
 
     def ls(self, path, detail=False):
         self._get_dirs()
         paths = {}
         for p, f in self.dir_cache.items():
-            p = p.rstrip('/')
-            if '/' in p:
-                root = p.rsplit('/', 1)[0]
+            p = p.rstrip("/")
+            if "/" in p:
+                root = p.rsplit("/", 1)[0]
             else:
-                root = ''
-            if root == path.rstrip('/'):
+                root = ""
+            if root == path.rstrip("/"):
                 paths[p] = f
             elif path and all(
-                    (a == b) for a, b
-                    in zip(path.split('/'), p.strip('/').split('/'))):
+                (a == b) for a, b in zip(path.split("/"), p.strip("/").split("/"))
+            ):
                 # implicit directory
-                ppath = '/'.join(p.split('/')[:len(path.split('/')) + 1])
+                ppath = "/".join(p.split("/")[: len(path.split("/")) + 1])
                 if ppath not in paths:
-                    out = {'name': ppath + '/', 'size': 0, 'type': 'directory'}
+                    out = {"name": ppath + "/", "size": 0, "type": "directory"}
                     paths[ppath] = out
 
-            elif all((a == b) for a, b
-                     in zip(path.split('/'), [''] + p.strip('/').split('/'))):
+            elif all(
+                (a == b)
+                for a, b in zip(path.split("/"), [""] + p.strip("/").split("/"))
+            ):
                 # root directory entry
-                ppath = p.rstrip('/').split('/', 1)[0]
+                ppath = p.rstrip("/").split("/", 1)[0]
                 if ppath not in paths:
-                    out = {'name': ppath + '/', 'size': 0, 'type': 'directory'}
+                    out = {"name": ppath + "/", "size": 0, "type": "directory"}
                     paths[ppath] = out
         out = list(paths.values())
         if detail:
             return out
         else:
-            return list(sorted(f['name'] for f in out))
+            return list(sorted(f["name"] for f in out))
 
     def __reduce_ex__(self, protocol):
-        return ZipFileSystem, (self.in_fo, )
+        return ZipFileSystem, (self.in_fo,)
 
     def cat(self, path):
         return self.zip.read(path)
 
-    def _open(self, path, mode='rb', **kwargs):
-        if mode != 'rb':
+    def _open(self, path, mode="rb", **kwargs):
+        if mode != "rb":
             raise NotImplementedError
         info = self.info(path)
-        out = self.zip.open(path, 'r')
-        out.size = info['size']
-        out.name = info['name']
+        out = self.zip.open(path, "r")
+        out.size = info["size"]
+        out.name = info["name"]
         return out
 
     def ukey(self, path):
